@@ -199,12 +199,13 @@ class LibraryExperiment(object):
         filtered_count_mat[self.pools] = counts
         self.count_mat = filtered_count_mat
         
-        
+
         unambiguous_data, ambiguous_data= get_ambiguity(self)
         unambiguous_locations =  get_unambiguous_locations(unambiguous_data, self)
         ambiguous_locations = predict_ambiguous_locations(ambiguous_data, self)
         locations = pd.concat([unambiguous_locations, ambiguous_locations])
-        
+        temppath = os.path.join("temp", "locations.csv")
+        locations.to_csv(temppath)
         # bad assertions/ count mat is longer than locations as it contains unpredictable mutants
         # assert np.all(locations["Feature"].values == self.count_mat["Feature"].values), \
         #     "Coordinates of locations and data not aligned!"
